summaryrefslogtreecommitdiffstats
path: root/GibberishAES.php
diff options
context:
space:
mode:
Diffstat (limited to 'GibberishAES.php')
-rw-r--r--GibberishAES.php12
1 files changed, 9 insertions, 3 deletions
diff --git a/GibberishAES.php b/GibberishAES.php
index 12d1d8a..4e8df5c 100644
--- a/GibberishAES.php
+++ b/GibberishAES.php
@@ -16,7 +16,7 @@
*
* OpenSSL functions installed and PHP version >= 5.3.3
* or
* Mcrypt functions installed.
*
* For PHP under version 7 it is recommendable you to install within your project
* "PHP 5.x support for random_bytes() and random_int()",
@@ -51,7 +51,7 @@
* @author Ivan Tcholakov <ivantcholakov@gmail.com>, 2012-2016.
* Code repository: @link https://github.com/ivantcholakov/gibberish-aes-php
*
- * @version 1.3.0
+ * @version 1.3.1
*
* @license The MIT License (MIT)
* @link http://opensource.org/licenses/MIT
@@ -249,7 +249,13 @@ class GibberishAES {
protected static function mcrypt_exists() {
if (!isset(self::$mcrypt_exists)) {
- self::$mcrypt_exists = function_exists('mcrypt_encrypt');
+
+ if (version_compare(PHP_VERSION, '7.1.0-alpha', '>=')) {
+ // Avoid using mcrypt on PHP 7.1.x since deprecation notices are thrown.
+ self::$mcrypt_exists = false;
+ } else {
+ self::$mcrypt_exists = function_exists('mcrypt_encrypt');
+ }
}
return self::$mcrypt_exists;
@@ -16,7 +16,7 @@
* OpenSSL functions installed and PHP version >= 5.3.3
* or
- * Mcrypt functions installed.
+ * Mcrypt functions installed and PHP version < 7.1.0-alpha
*
* For PHP under version 7 it is recommendable you to install within your project